#!/usr/bin/env node --require dotenv/config
"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = __importDefault(require("fs"));
const mongodb_1 = require("./mongodb");
const compile_1 = require("./compile");
const configPath = "./bson2ts.json";
const { MONGODB_URI, MONGODB_DB_NAME } = process.env;
function loadConfig() {
    if (!fs_1.default.existsSync(configPath)) {
        return {};
    }
    const config = fs_1.default.readFileSync(configPath).toString();
    return JSON.parse(config);
}
function main() {
    return __awaiter(this, void 0, void 0, function* () {
        if (!MONGODB_URI) {
            throw new Error("MONGODB_URI environment variable not defined");
        }
        if (!MONGODB_DB_NAME) {
            throw new Error("MONGODB_DB_NAME environment variable not defined");
        }
        // Load configuration
        const opts = loadConfig();
        // Get schemas for all collections from the MongoDB server
        const schemas = yield mongodb_1.getAllServerSchemas(MONGODB_URI, MONGODB_DB_NAME);
        console.log("Generating typescript types for MongoDB collection schemas");
        yield Promise.all(schemas.map(({ schema, collectionName }) => __awaiter(this, void 0, void 0, function* () {
            console.log((!schema ? "-" : "OK").padEnd(4), collectionName);
            // Do nothing when a collection has no schema
            if (!schema)
                return;
            const output = yield compile_1.compileBSON(schema, opts);
            const filename = typeof schema.title === "string" ? schema.title : "";
            if (!filename)
                throw new Error("A schema title is required");
            // Store types
            fs_1.default.writeFileSync(`./src/__generated__/${filename}.ts`, output);
        })));
    });
}
main().catch((error) => console.error(error));
//# sourceMappingURL=cli.js.map